#! /usr/bin/env python

import sys

from numpy import (add, amin, amax, append, arange, array, column_stack, diag,
                   empty, finfo, float32, fromfile, intc, invert, isnan,
                   newaxis, NINF, outer, s_, sqrt, square, tile, vectorize)

from segway.run import (Runner, parse_options, SENTINEL, DTYPE_OBS_INT, DISTRIBUTION_ARCSINH_NORMAL, SUPERVISION_UNSUPERVISED)

class IntRunner(Runner):

     def save_observations_chunk(self, float_filepath, int_filepath, float_data,
                                seq_data, supervision_data):
        # input function in GMTK_ObservationMatrix.cc:
        # ObservationMatrix::readBinSentence

        # input per frame is a series of float32s, followed by a series of
        # int32s it is better to optimize both sides here by sticking all
        # the floats in one file, and the ints in another one

        int_blocks = []
        if float_data is not None:
            if self.distribution == DISTRIBUTION_ARCSINH_NORMAL:
                float_data = arcsinh(float_data)

            mask_missing = isnan(float_data)

            # output -> int_blocks
            # done in two steps so I can specify output type
            presence_data = empty(mask_missing.shape, DTYPE_OBS_INT)
            invert(mask_missing, presence_data)
            int_blocks.append(presence_data)

            float_data[mask_missing] = SENTINEL

            float_data.tofile(float_filepath)

            ### Xiaoyu
            # add one integer column storing integer data values
            int_value = float_data.astype(DTYPE_OBS_INT)
            # ??? dimension matches?
            int_blocks.append(int_value)


        if seq_data is not None:
            int_blocks.append(make_dinucleotide_int_data(seq_data))

        if supervision_data is not None:
            int_blocks.append(supervision_data)

        # XXXopt: use the correctly sized matrix in the first place
        int_data = column_stack(int_blocks)
        int_data.tofile(int_filepath)



     def set_num_tracks(self, num_tracks):
         ### Xiaoyu 
         # add one integer data column for each track  
         #num_int_cols = num_tracks
         num_int_cols = num_tracks * 2

         if self.use_dinucleotide:
             num_int_cols += NUM_SEQ_COLS
         if self.supervision_type != SUPERVISION_UNSUPERVISED:
             num_int_cols += 1

         self.num_tracks = num_tracks
         self.num_int_cols = num_int_cols




def main(args=sys.argv[1:]):

    # parse_options is NOT a class function
    options, args = parse_options(args)

    # fromoptions is a CLASS FUNCTION
    runner = IntRunner.fromoptions(args, options)

    return runner()

if __name__ == "__main__":
    sys.exit(main())
