    % -------------------------------------------------------------------------
    % changeSeg : in all frames beyond the 0th one, this variable is set
    % based on either segCountDown(-1) or, if segCountDown(0)=0 (which is
    % used to indicate that we are in an _exponential_ seg), then changeSeg
    % will be chosen randomly based on a CPT that is a function of the current
    % seg ...
    %
    % the switching parent which is in [0,K], is mapped down to just three
    % values using the mapping function "counter_map" as follows:
    %		if parent=0 --> 0
    %		if parent=1 --> 1
    %		if parent>1 --> 2
    % and these values in turn control which of the three conditionalparents
    % 'clauses' will be switched "on" ...

    variable: changeSeg {
	type: discrete hidden cardinality BINARY_CARD;
	switchingparents: segCountDown(-1) using mapping ("counter_map");
	conditionalparents: 
		seg(-1) using DenseCPT("leaveExpSeg_CPT")       % 0
	      |	nil using DeterministicCPT("setBinaryTRUE")     % 1
	      | nil using DeterministicCPT("setBinaryFALSE");   % 2
    }

    % -------------------------------------------------------------------------
    % seg : this variable indicates what seg we are currently in ... 
    % in all frames after the 0th one, the current seg will either be the
    % same as the previous seg, OR if changeSeg=TRUE, it will be chosen
    % based on what is allowed to follow seg(-1) 

    variable: seg {
	type: discrete hidden cardinality SEG_CARD;
	switchingparents: changeSeg(0) using mapping ("oneD_map");
	conditionalparents: 
		seg(-1) using DeterministicCPT("copySeg")	% 0
	      | seg(-1) using DenseCPT("segTrans_CPT");     % 1
    }

    % -------------------------------------------------------------------------
    % segCountDown : this variable is used to count *down* the duration
    % of a particular seg ... so the parents are :
    %	- from current frame : changeSeg (as a switching parent)
    %		if changeSeg=FALSE, decrement segCountDown(-1)
    %		if changeSeg=TRUE,  choose duration for new seg
    % note that the "decLength" decrements any incoming value that is greater
    % than 0 -- if the incoming (parent) value is 0, then the new value is
    % also 0 ...

    % cardinality ???

    variable: segCountDown {
	type: discrete hidden cardinality MAX_SEG_LENGTH_CARD;
	switchingparents: changeSeg(0) using mapping ("oneD_map");
	conditionalparents: 
	    segCountDown(-1) using DeterministicCPT("decLength")	% 0 
	  | seg(0) using DeterministicCPT("assignCount");		% 1 
    }

    % -------------------------------------------------------------------------
