%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This is the master file for the model_train graph
%

#include "commonParams.inc"

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                    DENSE PROBABILITY MASS FUNCTIONS                         %

DPMF_IN_FILE	inline
1
0   dpmf_always   1   1.0

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                              DIRICHLET TABLES                               %
% none needed at this time ...

DIRICHLET_TAB_IN_FILE	inline
0

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                               DECISION TREEs                                %
%									      %
% a decision tree is needed whenever we use a DeterministicCPT or a mapping;  %
% here we list first those DTs that are paired with a DeterministicCPT of the %
% same name (w/o the _DT ending), then those that are used as part of a       %
% mapping of some sort ...						      %

DT_IN_FILE	inline
11				% total number of decision trees to follow

0				% index
setZero_DT			% name
0				% no parents
    -1    0			% always return 0


1				% index
setOne_DT			% name
0				% no parents
    -1    1			% always return 1


2
copyParent_DT			% name
1									% one parent
    -1   {p0}			% just return parent value


3									% index
incParent_DT			% name
1									% one parent
    -1   {p0+1}		% return parent+1


% p0=0: seg_1 do not have length constrain 
% p0=STATE0_MIN_COUNTER: seg_0 reaches min length
4                                               % index
decParent_DT			                % name
1				                % one parent
    0  2  0,STATE0_MIN_COUNTER  default		% split on p0; 2 splits
      -1  0			                % if p0=0 or 31, return 0
      -1  {p0-1}		                % if p0>0, return p0-1


%
% this decision tree is used to constrain the final seg (which is the parent
% in this case), and the value returned is 1 if the final seg is a valid
% final seg, and is 0 if the final seg is NOT valid ...
%

5							% index
finalSeg_DT						% name
1							% one parent (seg)
    0  2  0:1  default		% split on p0; 2 splits
      -1  1			%     seg_0 and seg_1 are valid final segments
      -1  0			%     seg_2 is NOT a valid ending segment


% 
% this mapping is used for switching parents when we just want the mapping
% to imitate the parent value (typically binary) ...
%

6				% index
oneD_map			% name
1				% one parent
    -1  { p0 }			% return copy of parent


%
% this mapping is used to map the segCountDown variable from [0,N]
% down to just 3 classes:
% 0 ---> 0 (seg_1 or (seg_0 >= its min length))
% 2:STATE2_MIN_COUNTER ---> 0 (its max length >= seg_2 >= its min length)
% 1 ---> 1 (seg_2 = its max length)
% STATE2_MIN_COUNTER+1:STATE0_MAX_LEN, STATE0_MIN_COUNTER:STATE0_INIT_COUNTER
%   ---> 2 ((seg_0 < its min length) or (seg_2 < its min length))

7				                 % index
counter_map			                 % name
1				                 % one parent
    0    3   0,2:STATE2_MIN_COUNTER  1  default	 % split on p0; 3 splits
	-1  0   		% if counter=0 or 2 <= counter <= 23, return 0 
	-1  1	                % if counter=1, return 1 
	-1  2		        % otherwise ([24, 30] or [31, 60]), return 2 


8				% index
areDiff_map			% name
2				% two parents
    -1  { p0 != p1 }		% return TRUE if different


9                              % index
segCount_DT                     % name
1                               % one parent
    0    3   0   1   default    % split on P0; 3 splits
        -1  STATE0_INIT_COUNTER % initial count for seg_0 is 60
        -1  0                   % initial count for seg_1 is 0 (no length constraint)
        -1  STATE2_INIT_COUNTER % initial count for seg_2 is 30 (the max length of seg_2)


10                      % index
seg2segClass_DT         % name
1                       % one parent
   0  2  1  default     % split on p0; 2 splits
     -1  1              % if p0=1, return 1
     -1  0              % otherwise (p0=0 or p0=2), return 0


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                             DETERMINISTIC CPTs                              %
%									      %

DETERMINISTIC_CPT_IN_FILE	inline

7				% total number of Det CPTs to follow


0				% index
setBinaryFALSE			% name
0				% no parents
BINARY_CARD			% self-cardinality
setZero_DT			% DT name


1				% index
setBinaryTRUE			% name
0				% no parents
BINARY_CARD			% self-cardinality
setOne_DT			% DT name


2				% index
copySeg			% name
1				% one parent (seg)
SEG_CARD  SEG_CARD		% parent, then self cardinalities
copyParent_DT			% DT name

3				% index
decLength			% name
1				% one parent (length)
MAX_SEG_LENGTH_CARD  MAX_SEG_LENGTH_CARD
decParent_DT			% DT name

4				% index
finalSeg			% name
1				% one parent(seg)
SEG_CARD  BINARY_CARD		% parent, then self cardinalities
finalSeg_DT			% DT name

5                               % index
assignCount			% name
1				% one parent (length)
SEG_CARD  MAX_SEG_LENGTH_CARD
segCount_DT			% DT name

6                               % index
seg2segClass                    % name
1                               % one parent (seg)
SEG_CARD  SEG_CLASS_CARD        % parent, then self cardinalities
seg2segClass_DT                 % DT name

#ifndef INPUT_PARAMS_FILENAME


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                 DENSE CPTs                                  %
%									      %

DENSE_CPT_IN_FILE	inline

4 				% total number of dense CPTs to follow

% the startSeg_CPT will be initialized to have equal-probability for any
% "allowed" starting-seg, and *zero* probability for all the rest ...
%

0				% index
startSeg_CPT			% name
0				% no parents
SEG_CARD			% cardinality
0.5  0.5  0.0



% this CPT contains the probability of leaving a particular seg ...
% we need one row for each segment state, although in reality this will only
% be used for exponential segs
%
% as a sanity-check, any segment-state that is *not* exponential (and therefore
% should never query this CPT), we will set the probability of "leaving" to 0.

1				% index
leaveExpSeg_CPT		% name
1				% one parent
SEG_CARD    BINARY_CARD
0.995     0.005		% background state -- expected to be long
0.990     0.010		% HS site state -- expected to be shorter
0.960     0.040		% Footprint state -- expected to be very short

% this CPT defines the allowed seg-transitions ... most segs can only 
% transition to one seg, although a few of the transitions are random
% ( seg-0, which is not currently used, will stay in seg-0 forever )
%
% note that seg-25, the "globular-only" seg is a sink: once a path comes
% into this seg, it may never leave ...

2				% index
segTrans_CPT			% name
1				% one parent
SEG_CARD    SEG_CARD
  0.   1.   0.			% seg0 --> seg1 ONLY
  0.3  0.   0.7 		% seg1 --> seg0 OR seg2
  0.   1.   0.			% seg2 --> seg1 ONLY


% this CPT defines P(dnasei-tag-counts | seg)
3                               % index
segDnasei_CPT                   % name
1                               % one parent (segClass)
SEG_CLASS_CARD    DNASEI_CARD
0.4339 0.2447 0.1203 6.4560e-2 3.8863e-2 2.5183e-2 1.6915e-2 1.1892e-2 8.2194e-3 6.3832e-3 5.1299e-3 3.9834e-3 3.1187e-3 2.5261e-3 1.9431e-3 3.0119e-3 2.9147e-3 2.6912e-3 1.9626e-3 1.8028e-3
0.1236 0.1483 0.1282 0.1004 7.8573e-2 6.1606e-2 4.8814e-2 4.0077e-2 3.2860e-2 2.7827e-2 2.3390e-2 2.0426e-2 1.6979e-2 1.4605e-2 1.3126e-2 2.1404e-2 2.2627e-2 2.9533e-2 2.8298e-2 1.9355e-2



% for parallel mode
#else

DENSE_CPT_IN_FILE INPUT_PARAMS_FILENAME ascii
REAL_MAT_IN_FILE INPUT_PARAMS_FILENAME ascii

#endif

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                    END				      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
